@@ -1,3 +1,5 @@
+import json
+
 from stream_chat.exceptions import StreamChannelException
 
 
@@ -71,7 +73,7 @@ class Channel(object):
         :param user_id: the ID of the user creating this channel
         :return:
         """
-        self.custom_data["created_by"] = dict(id=user_id)
+        self.custom_data["created_by"] = {"id": user_id}
         return self.query(watch=False, state=False, presence=False)
 
     def query(self, **options):
@@ -81,8 +83,7 @@ class Channel(object):
         :param options: the query options, check docs on https://getstream.io/chat/docs/
         :return: Returns a query response
         """
-        payload = {"state": True, "data": self.custom_data}
-        payload.update(options)
+        payload = {"state": True, "data": self.custom_data, **options}
 
         url = "channels/{}".format(self.channel_type)
         if self.id is not None:
@@ -95,6 +96,32 @@ class Channel(object):
 
         return state
 
+    def query_members(self, filter_conditions, sort=None, **options):
+        """
+        Query the API for this channel to filter, sort and paginate its members efficiently.
+
+        :param filter_conditions: filters, checks docs on https://getstream.io/chat/docs/
+        :param sort: sorting field and direction slice, check docs on https://getstream.io/chat/docs/
+        :param options: pagination or members based channel searching details
+        :return: Returns members response
+
+        eg.
+        channel.query_members(filter_conditions={"name": "tommaso"},
+                              sort=[{"field": "created_at", "direction": -1}],
+                              offset=0,
+                              limit=10)
+        """
+
+        payload = {
+            "id": self.id,
+            "type": self.channel_type,
+            "filter_conditions": filter_conditions,
+            "sort": sort or [],
+            **options,
+        }
+        response = self.client.get("members", params={"payload": json.dumps(payload)})
+        return response["members"]
+
     def update(self, channel_data, update_message=None):
         """
         Edit the channel's custom properties
@@ -261,6 +288,4 @@ class Channel(object):
 
 
 def add_user_id(payload, user_id):
-    payload = payload.copy()
-    payload.update(dict(user=dict(id=user_id)))
-    return payload
+    return {**payload, "user": {"id": user_id}}
