@@ -40,7 +40,7 @@ class StreamChat(object):
         self.session = requests.Session()
 
     def get_default_params(self):
-        return dict(api_key=self.api_key)
+        return {"api_key": self.api_key}
 
     def _parse_response(self, response):
         try:
@@ -127,33 +127,27 @@ class StreamChat(object):
         return self.get("users/{}/export".format(user_id), options)
 
     def ban_user(self, target_id, **options):
-        data = dict(target_user_id=target_id)
-        data.update(options)
+        data = {"target_user_id": target_id, **options}
         return self.post("moderation/ban", data=data)
 
     def unban_user(self, target_id, **options):
-        params = dict(target_user_id=target_id)
-        params.update(options)
+        params = {"target_user_id": target_id, **options}
         return self.delete("moderation/ban", params)
 
     def flag_message(self, target_id, **options):
-        data = dict(target_message_id=target_id)
-        data.update(options)
+        data = {"target_message_id": target_id, **options}
         return self.post("moderation/flag", data=data)
 
     def unflag_message(self, target_id, **options):
-        data = dict(target_message_id=target_id)
-        data.update(options)
+        data = {"target_message_id": target_id, **options}
         return self.post("moderation/unflag", data=data)
 
     def flag_user(self, target_id, **options):
-        data = dict(target_user_id=target_id)
-        data.update(options)
+        data = {"target_user_id": target_id, **options}
         return self.post("moderation/flag", data=data)
 
     def unflag_user(self, target_id, **options):
-        data = dict(target_user_id=target_id)
-        data.update(options)
+        data = {"target_user_id": target_id, **options}
         return self.post("moderation/unflag", data=data)
 
     def mute_user(self, target_id, user_id, **options):
@@ -165,7 +159,7 @@ class StreamChat(object):
         :param options: additional mute options
         :return:
         """
-        data = dict(target_id=target_id, user_id=user_id, **options)
+        data = {"target_id": target_id, "user_id": user_id, **options}
         return self.post("moderation/mute", data=data)
 
     def unmute_user(self, target_id, user_id):
@@ -177,7 +171,7 @@ class StreamChat(object):
         :return:
         """
 
-        data = dict(target_id=target_id, user_id=user_id)
+        data = {"target_id": target_id, "user_id": user_id}
         return self.post("moderation/unmute", data=data)
 
     def mark_all_read(self, user_id):
@@ -245,6 +239,21 @@ class StreamChat(object):
         """
         return Channel(self, channel_type, channel_id, data)
 
+    def list_commands(self):
+        return self.get("commands")
+
+    def create_command(self, data):
+        return self.post("commands", data=data)
+
+    def delete_command(self, name):
+        return self.delete("commands/{}".format(name))
+
+    def get_command(self, name):
+        return self.get("commands/{}".format(name))
+
+    def update_command(self, name, **settings):
+        return self.put("commands/{}".format(name), data=settings)
+
     def add_device(self, device_id, push_provider, user_id):
         """
         Add a device to a user
@@ -292,8 +301,7 @@ class StreamChat(object):
         return signature == x_signature
 
     def search(self, filter_conditions, query, **options):
-        params = options.copy()
-        params.update({"filter_conditions": filter_conditions, "query": query})
+        params = {**options, "filter_conditions": filter_conditions, "query": query}
         return self.get("search", params={"payload": json.dumps(params)})
 
     def send_file(self, uri, url, name, user, content_type=None):
